#!/bin/bash

load_trigger=${REVEAL_LOAD_FOR_CONFIGURATION:=Debug}

if [ "${CONFIGURATION}" != "${load_trigger}" ]; then
    echo "Reveal Server not copied: Current build configuration is not '${load_trigger}'."
    exit 0
fi

if [ "${PLATFORM_NAME}" == "appletvos" ]; then
    REVEAL_LIB_DIR="tvOS"
else
    REVEAL_LIB_DIR="iOS"
fi

OTHER_CODE_SIGN_FLAGS=${OTHER_CODE_SIGN_FLAGS:=}
REVEAL_SERVER_FILENAME="RevealServer.framework"
REVEAL_SERVER_PATH="${HOME}/Library/Application Support/Reveal/RevealServer/${REVEAL_LIB_DIR}/${REVEAL_SERVER_FILENAME}"
SIGNING_IDENTITY="${EXPANDED_CODE_SIGN_IDENTITY:-$CODE_SIGN_IDENTITY}"

if [ -e "${REVEAL_SERVER_PATH}" ]; then
    cp -Rf "$REVEAL_SERVER_PATH" "${CODESIGNING_FOLDER_PATH}/"
    if [ -n "${SIGNING_IDENTITY}" ]; then
        codesign ${OTHER_CODE_SIGN_FLAGS} \
            --force --sign "${SIGNING_IDENTITY}" \
            "${CODESIGNING_FOLDER_PATH}/${REVEAL_SERVER_FILENAME}"
    fi

    echo "${REVEAL_SERVER_FILENAME} is included in this build, and has been copied to $CODESIGNING_FOLDER_PATH"

    LLDB_INIT_FILE=~/.lldbinit
    LLDB_INIT_MAGIC_STRING="### Reveal LLDB commands support"

    if [ ! -e "${LLDB_INIT_FILE}" ] || ! grep -q "${LLDB_INIT_MAGIC_STRING}" "${LLDB_INIT_FILE}"; then
        echo "Note: it looks like Reveal Server's debugger commands are not installed. Please refer to 'Loading the Reveal Server via an Xcode Breakpoint' section of the Integration Guide for information about loading Reveal Server included in this build."
    fi
else
  echo "Reveal Server not copied: RevealServer.framework could not be found."
fi
